@@ -28,6 +28,7 @@ class Capture(gobject.GObject):
     CAPTURE_STDOUT = 0x01
     CAPTURE_STDERR = 0x02
     CAPTURE_BOTH   = 0x03
+    CAPTURE_NEEDS_SHELL = 0x04
     
     WRITE_BUFFER_SIZE = 0x4000
 
@@ -43,7 +44,7 @@ class Capture(gobject.GObject):
         self.pipe = None
         self.env = env
         self.cwd = cwd
-        self.flags = self.CAPTURE_BOTH
+        self.flags = self.CAPTURE_BOTH | self.CAPTURE_NEEDS_SHELL
         self.command = command
         self.input_text = None
 
@@ -69,7 +70,7 @@ class Capture(gobject.GObject):
         # Initialize pipe
         popen_args = {
             'cwd'  : self.cwd,
-            'shell': False,
+            'shell': self.flags & self.CAPTURE_NEEDS_SHELL,
             'env'  : self.env
         }
         
@@ -78,10 +79,7 @@ class Capture(gobject.GObject):
         if self.flags & self.CAPTURE_STDOUT:
             popen_args['stdout'] = subprocess.PIPE
         if self.flags & self.CAPTURE_STDERR:
-            if self.flags & self.CAPTURE_STDOUT:
-                popen_args['stderr'] = subprocess.STDOUT
-            else:
-                popen_args['stderr'] = subprocess.PIPE
+            popen_args['stderr'] = subprocess.PIPE
 
         self.tried_killing = False
         self.idle_write_id = 0
@@ -106,7 +104,7 @@ class Capture(gobject.GObject):
                                  gobject.IO_IN | gobject.IO_HUP,
                                  self.on_output)
 
-        elif self.flags & self.CAPTURE_STDERR:
+        if self.flags & self.CAPTURE_STDERR:
             # Set non blocking
             flags = fcntl.fcntl(self.pipe.stderr.fileno(), fcntl.F_GETFL) | os.O_NONBLOCK
             fcntl.fcntl(self.pipe.stderr.fileno(), fcntl.F_SETFL, flags)
@@ -202,7 +200,7 @@ class Capture(gobject.GObject):
                 os.kill(self.pipe.pid, signal.SIGTERM)
                 self.tried_killing = True
             else:
-                os.killpg(self.pipe.pid, sigal.SIGKILL)
+                os.kill(self.pipe.pid, signal.SIGKILL)
 
     def on_child_end(self, pid, error_code):
         # In an idle, so it is emitted after all the std*-line signals
